==> guikachu-0.4.tar.gz: guikachu-0.4/src/resource.h <==
//$Id: resource.h,v 1.8 2001/04/15 13:03:53 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_RESOURCE_H
#define GUIKACHU_RESOURCE_H

#include <string>
#include <iostream>
#include <gnome-xml/tree.h>
#include <sigc++/basic_signal.h>

#define GUIKACHU_RESOURCE_PROP(param,type)			\
	protected:						\
	    type param;						\
	public:							\
	    type get_##param () { return param; };		\
	    void set_##param (const type & param##_) { param = param##_; changed (); };

namespace Guikachu
{
    namespace Resources
    {
	enum Type
	{
	    RESOURCE_DIALOG,
	    RESOURCE_STRING,
	    RESOURCE_MENU,
	    RESOURCE_FORM
	};
	
	class Resource;
    }
}

#include "resource-manager.h"

namespace Guikachu
{
    namespace Resources
    {
	class Resource: public SigC::Object
	{
	protected:
	    string id;
	public:
	    virtual ~Resource () {};

	    // Resource managment functions
	    virtual Type get_type () const = 0;

	    string get_id ();
	    void   set_id (const string& id);

	    SigC::Signal0<void> changed;

	    // User interface hook
	    virtual void show_ui () = 0;
	    
	private:
	    // Persistance
	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node) = 0;
	    virtual void save (xmlNodePtr node) const = 0;
	    virtual void save_rcp (ostream &ostr) const = 0;
	    friend ostream& operator<< (ostream &ostr, const Resource *res);

	    friend class ResourceManager;
	};
	
	ostream& operator<< (ostream &ostr, const Resource* res);
    };
};

#endif /* !GUIKACHU_RESOURCE_H */

==> guikachu-0.8.tar.gz: guikachu-0.8/src/resource.h <==
//$Id: resource.h,v 1.10 2001/05/09 16:07:03 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_RESOURCE_H
#define GUIKACHU_RESOURCE_H

#include <string>
#include <iostream>
#include <gnome-xml/tree.h>
#include <sigc++/basic_signal.h>

#include "resource-util.h"

namespace Guikachu
{
    namespace Resources
    {
	enum Type
	{
	    RESOURCE_DIALOG,
	    RESOURCE_STRING,
	    RESOURCE_MENU,
	    RESOURCE_FORM
	};
	
	class Resource;
    }
}

#include "resource-manager.h"

namespace Guikachu
{
    namespace Resources
    {
	class Resource: public SigC::Object
	{
	protected:
	    string id;
	public:
	    virtual ~Resource () {};

	    // Resource managment functions
	    virtual Type get_type () const = 0;

	    string get_id ();
	    void   set_id (const string& id);

	    SigC::Signal0<void> changed;

	    // User interface hook
	    virtual void show_ui () = 0;
	    
	private:
	    // Persistance
	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node) = 0;
	    virtual void save (xmlNodePtr node) const = 0;
	    virtual void save_rcp (ostream &ostr) const = 0;
	    friend ostream& operator<< (ostream &ostr, const Resource *res);

	    friend class ResourceManager;
	};
	
	ostream& operator<< (ostream &ostr, const Resource* res);
    };
};

#endif /* !GUIKACHU_RESOURCE_H */
